energomera

package module
v0.0.0-...-ca6d86a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 27, 2020 License: MIT Imports: 1 Imported by: 2

README

Energomera protocol encoder / decoder package

This Go package is fully based on Python code which is used to encode and decode Energomera protocol messages,
which can be used to communicate with electricity meter(s) over rs-485 protocol.

For more information check the source code documentation.

Projects using energomera package

Usage / available functions

import (
     "github.com/peak-load/energomera"
)

Package provides two functions:

  • energomera.DataDecode(sdata []byte) (msg map[string]string)
  • energomera.DataEncode(msg map[string]string) (sdata []byte)

Credits

Original Python code:

Documentation / resources

License

MIT License, see LICENSE

Documentation

Overview

Package energomera provides primitives for decoding and encoding GOST-R MEK 61107-2001 (ГОСТ Р МЭК 61107-2001) protocol messages.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DataDecode

func DataDecode(sdata []byte) (msg map[string]string)

Energomera data decoder is used to decode message received from bus

func DataEncode

func DataEncode(msg map[string]string) (sdata []byte)

Energomera data encoder is used to encode data which will be sent over bus

Types

This section is empty.

Jump to